# Dython

[![PyPI Version](https://img.shields.io/pypi/v/dython.svg)](https://pypi.org/project/dython/)
[![Python Version](https://img.shields.io/pypi/pyversions/dython.svg)](https://pypi.org/project/dython/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/dython)](https://pypistats.org/packages/dython)

A set of **D**ata analysis tools in p**YTHON** 3.x.

Dython was designed with analysis usage in mind - meaning ease-of-use, functionality and readability are the core 
values of this library. Production-grade performance, on the other hand, were not considered.

## Documentation:
Modules documentation can be found on [shakedzy.xyz/dython](http://shakedzy.xyz/dython)

## Installation:
Dython can be installed directly using `pip`:
```
pip install dython
```
If you wish to install from source:
```
pip install git+https://github.com/shakedzy/dython.git
```

**Dependencies:** `numpy`, `pandas`, `seaborn`, `scipy`, `matplotlib`, `sklearn`

## Contributing:
Contributions are always welcomed - if you found something you can fix, or have an idea for a new feature, feel free to write it and open a pull request. Please make sure to go over the [contributions guidelines](https://github.com/shakedzy/dython/blob/master/CONTRIBUTING.md).

## Change log:
Change log is available, see [CHANGELOG.md](https://github.com/shakedzy/dython/blob/master/CHANGELOG.md).

## Related blogposts:
* Read more about the categorical tools on [The Search for Categorical Correlation](https://medium.com/@shakedzy/the-search-for-categorical-correlation-a1cf7f1888c9)
* Read more about using ROC graphs on [Hard ROC: Really Understanding & Properly Using ROC and AUC](https://medium.com/@shakedzy/hard-roc-really-understanding-and-properly-using-roc-and-auc-13413cf0dc24)
